@@ -16,6 +16,7 @@ use serde_json::{json, Value};
 use std::collections::{HashMap, HashSet};
 use std::fs::File;
 use std::path::{Path, PathBuf};
+use std::sync::Arc;
 use sway_core::{BuildConfig, CompileAstResult, Namespace, TreeType, TypedParseTree};
 
 pub fn build(command: JsonAbiCommand) -> Result<Value, String> {
@@ -70,8 +71,9 @@ pub fn build(command: JsonAbiCommand) -> Result<Value, String> {
 
             // Download a non-local dependency if the `git` property is set in this dependency.
             if let Some(git) = &dep.git {
+                let fully_qualified_dep_name = format!("{}-{}", dependency_name, git);
                 let downloaded_dep_path = match dependency::download_github_dep(
-                    dependency_name,
+                    &fully_qualified_dep_name,
                     git,
                     &dep.branch,
                     &dep.version,
@@ -118,7 +120,7 @@ pub fn build(command: JsonAbiCommand) -> Result<Value, String> {
 
     if let Some(outfile) = json_outfile {
         let file = File::create(outfile).map_err(|e| e.to_string())?;
-        serde_json::to_writer(&file, &output_json.clone()).map_err(|e| e.to_string())?;
+        serde_json::to_writer(&file, &output_json).map_err(|e| e.to_string())?;
     } else {
         println!("{}", output_json);
     }
@@ -128,11 +130,11 @@ pub fn build(command: JsonAbiCommand) -> Result<Value, String> {
 
 /// Takes a dependency and returns a namespace of exported things from that dependency
 /// trait implementations are included as well
-fn compile_dependency_lib<'source, 'manifest>(
+fn compile_dependency_lib<'manifest>(
     project_file_path: &Path,
     dependency_name: &'manifest str,
     dependency_lib: &mut Dependency,
-    namespace: &mut Namespace<'source>,
+    namespace: &mut Namespace,
     dependency_graph: &mut HashMap<String, HashSet<String>>,
     silent_mode: bool,
     offline_mode: bool,
@@ -147,8 +149,9 @@ fn compile_dependency_lib<'source, 'manifest>(
     };
     // Download a non-local dependency if the `git` property is set in this dependency.
     if let Some(ref git) = details.git {
+        let fully_qualified_dep_name = format!("{}-{}", dependency_name, git);
         let downloaded_dep_path = match dependency::download_github_dep(
-            dependency_name,
+            &fully_qualified_dep_name,
             git,
             &details.branch,
             &details.version,
@@ -224,7 +227,7 @@ fn compile_dependency_lib<'source, 'manifest>(
         main_file,
         &manifest_of_dep.project.name,
         &dep_namespace,
-        build_config.clone(),
+        build_config,
         dependency_graph,
         silent_mode,
     )?;
@@ -235,14 +238,14 @@ fn compile_dependency_lib<'source, 'manifest>(
     Ok(json_abi)
 }
 
-fn compile_library<'source, 'manifest>(
-    source: &'source str,
+fn compile_library(
+    source: Arc<str>,
     proj_name: &str,
-    namespace: &Namespace<'source>,
+    namespace: &Namespace,
     build_config: BuildConfig,
     dependency_graph: &mut HashMap<String, HashSet<String>>,
     silent_mode: bool,
-) -> Result<(Namespace<'source>, Vec<Function>), String> {
+) -> Result<(Namespace, Vec<Function>), String> {
     let res = sway_core::compile_to_ast(source, namespace, &build_config, dependency_graph);
     match res {
         CompileAstResult::Success {
@@ -253,12 +256,7 @@ fn compile_library<'source, 'manifest>(
             let errors = vec![];
             match tree_type {
                 TreeType::Library { name } => {
-                    print_on_success(
-                        silent_mode,
-                        proj_name,
-                        warnings,
-                        TreeType::Library { name: name.clone() },
-                    );
+                    print_on_success(silent_mode, proj_name, warnings, TreeType::Library { name });
                     let json_abi = generate_json_abi(&Some(*parse_tree.clone()));
                     Ok((parse_tree.into_namespace(), json_abi))
                 }
@@ -275,15 +273,15 @@ fn compile_library<'source, 'manifest>(
     }
 }
 
-fn compile<'source, 'manifest>(
-    source: &'source str,
+fn compile(
+    source: Arc<str>,
     proj_name: &str,
-    namespace: &Namespace<'source>,
+    namespace: &Namespace,
     build_config: BuildConfig,
     dependency_graph: &mut HashMap<String, HashSet<String>>,
     silent_mode: bool,
 ) -> Result<Vec<Function>, String> {
-    let res = sway_core::compile_to_ast(&source, namespace, &build_config, dependency_graph);
+    let res = sway_core::compile_to_ast(source, namespace, &build_config, dependency_graph);
     match res {
         CompileAstResult::Success {
             parse_tree,
