@@ -8,6 +8,7 @@ use crate::{
 };
 use std::fs::File;
 use std::io::Write;
+use std::sync::Arc;
 use sway_core::{FinalizedAsm, TreeType};
 use sway_utils::{constants, find_manifest_dir};
 
@@ -27,8 +28,10 @@ pub fn build(command: BuildCommand) -> Result<Vec<u8>, String> {
 
     let BuildCommand {
         binary_outfile,
+        use_ir,
         print_finalized_asm,
         print_intermediate_asm,
+        print_ir,
         offline_mode,
         silent_mode,
         ..
@@ -62,8 +65,10 @@ pub fn build(command: BuildCommand) -> Result<Vec<u8>, String> {
         file_name.to_path_buf(),
         manifest_dir.clone(),
     )
+    .use_ir(use_ir || print_ir) // --print-ir implies --use-ir.
     .print_finalized_asm(print_finalized_asm)
-    .print_intermediate_asm(print_intermediate_asm);
+    .print_intermediate_asm(print_intermediate_asm)
+    .print_ir(print_ir);
 
     let mut dependency_graph = HashMap::new();
 
@@ -105,11 +110,11 @@ pub fn build(command: BuildCommand) -> Result<Vec<u8>, String> {
 
 /// Takes a dependency and returns a namespace of exported things from that dependency
 /// trait implementations are included as well
-fn compile_dependency_lib<'n, 'source, 'manifest>(
+fn compile_dependency_lib<'manifest>(
     project_file_path: &Path,
     dependency_name: &'manifest str,
     dependency_lib: &mut Dependency,
-    namespace: &mut Namespace<'source>,
+    namespace: &mut Namespace,
     dependency_graph: &mut HashMap<String, HashSet<String>>,
     silent_mode: bool,
     offline_mode: bool,
@@ -124,8 +129,11 @@ fn compile_dependency_lib<'n, 'source, 'manifest>(
     };
     // Download a non-local dependency if the `git` property is set in this dependency.
     if let Some(ref git) = details.git {
+        // the qualified name of the dependency includes its source and some metadata to prevent
+        // conflating dependencies from different sources
+        let fully_qualified_dep_name = format!("{}-{}", dependency_name, git);
         let downloaded_dep_path = match dependency::download_github_dep(
-            dependency_name,
+            &fully_qualified_dep_name,
             git,
             &details.branch,
             &details.version,
@@ -232,14 +240,14 @@ fn compile_dependency_lib<'n, 'source, 'manifest>(
     Ok(())
 }
 
-fn compile_library<'source>(
-    source: &'source str,
+fn compile_library(
+    source: Arc<str>,
     proj_name: &str,
-    namespace: &Namespace<'source>,
+    namespace: &Namespace,
     build_config: BuildConfig,
     dependency_graph: &mut HashMap<String, HashSet<String>>,
     silent_mode: bool,
-) -> Result<Namespace<'source>, String> {
+) -> Result<Namespace, String> {
     let res = sway_core::compile_to_asm(source, namespace, build_config, dependency_graph);
     match res {
         CompilationResult::Library {
@@ -263,10 +271,10 @@ fn compile_library<'source>(
     }
 }
 
-fn compile<'n, 'source>(
-    source: &'source str,
+fn compile(
+    source: Arc<str>,
     proj_name: &str,
-    namespace: &Namespace<'source>,
+    namespace: &Namespace,
     build_config: BuildConfig,
     dependency_graph: &mut HashMap<String, HashSet<String>>,
     silent_mode: bool,
@@ -275,27 +283,27 @@ fn compile<'n, 'source>(
     match res {
         BytecodeCompilationResult::Success { bytes, warnings } => {
             print_on_success(silent_mode, proj_name, warnings, TreeType::Script {});
-            return Ok(bytes);
+            Ok(bytes)
         }
         BytecodeCompilationResult::Library { warnings } => {
             print_on_success_library(silent_mode, proj_name, warnings);
-            return Ok(vec![]);
+            Ok(vec![])
         }
         BytecodeCompilationResult::Failure { errors, warnings } => {
             print_on_failure(silent_mode, warnings, errors);
-            return Err(format!("Failed to compile {}", proj_name));
+            Err(format!("Failed to compile {}", proj_name))
         }
     }
 }
 
-fn compile_to_asm<'sc>(
-    source: &'sc str,
+fn compile_to_asm(
+    source: Arc<str>,
     proj_name: &str,
-    namespace: &Namespace<'sc>,
+    namespace: &Namespace,
     build_config: BuildConfig,
     dependency_graph: &mut HashMap<String, HashSet<String>>,
     silent_mode: bool,
-) -> Result<FinalizedAsm<'sc>, String> {
+) -> Result<FinalizedAsm, String> {
     let res = sway_core::compile_to_asm(source, namespace, build_config, dependency_graph);
     match res {
         CompilationResult::Success { asm, warnings } => {
