@@ -1,9 +1,11 @@
 use crate::utils::manifest::Manifest;
 use anyhow::{anyhow, bail, Context, Result};
-use curl::easy::Easy;
 use dirs::home_dir;
 use flate2::read::GzDecoder;
 use serde::{Deserialize, Serialize};
+use std::collections::hash_map::DefaultHasher;
+use std::hash::{Hash, Hasher};
+use std::io::Read;
 use std::{
     collections::HashMap,
     fs,
@@ -102,13 +104,18 @@ pub fn download_github_dep(
         Some(p) => p.to_str().unwrap().to_owned(),
     };
 
+    // hash the dep name into a number to avoid bad characters
+    let mut s = DefaultHasher::new();
+    dep_name.hash(&mut s);
+    let hashed_dep_name = s.finish().to_string();
+
     // Version tag takes precedence over branch reference.
     let out_dir = match &version {
         Some(v) => PathBuf::from(format!(
             "{}/{}/{}/{}",
             home_dir,
             constants::FORC_DEPENDENCIES_DIRECTORY,
-            dep_name,
+            hashed_dep_name,
             v
         )),
         // If no version specified, check if a branch was specified
@@ -117,7 +124,7 @@ pub fn download_github_dep(
                 "{}/{}/{}/{}",
                 home_dir,
                 constants::FORC_DEPENDENCIES_DIRECTORY,
-                dep_name,
+                hashed_dep_name,
                 b
             )),
             // If no version and no branch, use default
@@ -125,7 +132,7 @@ pub fn download_github_dep(
                 "{}/{}/{}/default",
                 home_dir,
                 constants::FORC_DEPENDENCIES_DIRECTORY,
-                dep_name
+                hashed_dep_name
             )),
         },
     };
@@ -221,27 +228,11 @@ pub fn build_github_repo_api_url(
 
 pub fn download_tarball(url: &str, out_dir: &Path) -> Result<String> {
     let mut data = Vec::new();
-    let mut handle = Easy::new();
 
     // Download the tarball.
-    handle.url(url).context("failed to configure tarball URL")?;
-    handle
-        .follow_location(true)
-        .context("failed to configure follow location")?;
-
-    handle
-        .useragent("forc-builder")
-        .context("failed to configure User-Agent")?;
-    {
-        let mut transfer = handle.transfer();
-        transfer
-            .write_function(|new_data| {
-                data.extend_from_slice(new_data);
-                Ok(new_data.len())
-            })
-            .context("failed to write download data")?;
-        transfer.perform().context("failed to download tarball")?;
-    }
+    let handle = ureq::builder().user_agent("forc-builder").build();
+    let resp = handle.get(url).call()?;
+    resp.into_reader().read_to_end(&mut data)?;
 
     // Unpack the tarball.
     Archive::new(GzDecoder::new(Cursor::new(data)))
